@@ -1,8 +1,8 @@
 /*
- * util.c - special built-in shell utilities for osh
+ * util.c - special built-in shell utilities for etsh
  */
 /*-
- * Copyright (c) 2004-2017
+ * Copyright (c) 2004-2018
  *	Jeffrey Allen Neitzel <jan (at) etsh (dot) io>.
  *	All rights reserved.
  *
@@ -26,7 +26,7 @@
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
  * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	@(#)$Id: b3943d8a3fb4db9aa23b30b79ebfef54ab9b68cc $
+ *	@(#)$Id: a3eb4fa5ff6086b5c5837fb1d48f0f2fdadf2c3d $
  */
 /*
  *	Derived from: osh-20080629
@@ -67,10 +67,10 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#define	OSH_SHELL
+#define	ETSH_SHELL
 
 #include "defs.h"
-#include "err.h"
+#include "sh_err.h"
 #include "pexec.h"
 #include "sh.h"
 #include "strtoint.h"
@@ -107,7 +107,7 @@ uexec(enum sbikey key, int ac, char **av)
 	case SBI_GOTO:	util = &sbi_goto;	break;
 	case SBI_IF:	util = &sbi_if;		break;
 	default:
-		err(FC_ERR, FMT3S, getmyname(), __func__, "Invalid utility");
+		sh_err(FC_ERR, FMT3S, getmyname(), __func__, "Invalid utility");
 		/*NOTREACHED*/
 		return FC_ERR;
 	}
@@ -204,17 +204,17 @@ sbi_fd2(int argc, char **argv)
 
 	if (file != NULL) {
 		if ((nfd = open(file, O_WRONLY|O_APPEND|O_CREAT, 0666)) == -1)
-			err(FC_ERR, FMT3S, getmyname(), file, ERR_CREATE);
+			sh_err(FC_ERR, FMT3S, getmyname(), file, ERR_CREATE);
 		if (dup2(nfd, efd) == -1)
-			err(FC_ERR, FMT2S, getmyname(), strerror(errno));
+			sh_err(FC_ERR, FMT2S, getmyname(), strerror(errno));
 		if (eopt && dup2(efd, ofd) == -1)
-			err(FC_ERR, FMT2S, getmyname(), strerror(errno));
+			sh_err(FC_ERR, FMT2S, getmyname(), strerror(errno));
 		(void)close(nfd);
 	} else {
 		if (eopt)
 			ofd = FD2, efd = FD1;
 		if (dup2(ofd, efd) == -1)
-			err(FC_ERR, FMT2S, getmyname(), strerror(errno));
+			sh_err(FC_ERR, FMT2S, getmyname(), strerror(errno));
 	}
 
 	/*
@@ -224,7 +224,7 @@ sbi_fd2(int argc, char **argv)
 	if (IS_SBI(key))
 		return uexec(key, argc, argv);
 
-	(void)err_pexec(argv[0], argv);
+	(void)pexec_err(argv[0], argv);
 	/*NOTREACHED*/
 	return FC_ERR;
 }
@@ -233,7 +233,7 @@ static void
 fd2_usage(void)
 {
 
-	err(FC_ERR, FD2_USAGE, getmyname());
+	sh_err(FC_ERR, FD2_USAGE, getmyname());
 }
 
 static	off_t	offset;
@@ -260,11 +260,11 @@ sbi_goto(int argc, char **argv)
 	setmyname(argv[0]);
 
 	if (argc < 2 || *argv[1] == EOS || isatty(FD0) != 0)
-		err(FC_ERR, FMT2S, getmyname(), ERR_GENERIC);
+		sh_err(FC_ERR, FMT2S, getmyname(), ERR_GENERIC);
 	if ((siz = strlen(argv[1]) + 1) > sizeof(label))
-		err(FC_ERR, FMT3S, getmyname(), argv[1], ERR_LABTOOLONG);
+		sh_err(FC_ERR, FMT3S, getmyname(), argv[1], ERR_LABTOOLONG);
 	if (lseek(FD0, (off_t)0, SEEK_SET) == -1)
-		err(FC_ERR, FMT2S, getmyname(), ERR_SEEK);
+		sh_err(FC_ERR, FMT2S, getmyname(), ERR_SEEK);
 
 	while (getlabel(label, *argv[1] & 0377, siz))
 		if (strcmp(label, argv[1]) == 0) {
@@ -291,7 +291,7 @@ getlabel(char *buf, int fc, size_t siz)
 
 	while ((c = xgetc()) != EOF) {
 		/* `:' may be preceded by blanks. */
-		while (c == SPACE || c == TAB)
+		while (c == SPC || c == TAB)
 			c = xgetc();
 		if (c != COLON) {
 			while (c != EOL && c != EOF)
@@ -300,7 +300,7 @@ getlabel(char *buf, int fc, size_t siz)
 		}
 
 		/* Prepare for possible label. */
-		while ((c = xgetc()) == SPACE || c == TAB)
+		while ((c = xgetc()) == SPC || c == TAB)
 			;	/* nothing   */
 		if (c != fc)	/* not label */
 			continue;
@@ -311,7 +311,7 @@ getlabel(char *buf, int fc, size_t siz)
 		 */
 		b = buf;
 		do {
-			if (c == EOL || c == SPACE || c == TAB || c == EOF) {
+			if (c == EOL || c == SPC || c == TAB || c == EOF) {
 				*b = EOS;
 				break;
 			}
@@ -444,7 +444,7 @@ e3(void)
 	char *a, *b, *c;
 
 	if ((a = nxtarg(RETERR)) == NULL)
-		err(FC_ERR, FMT3S, getmyname(), iav[iap - 2], ERR_EXPR);
+		sh_err(FC_ERR, FMT3S, getmyname(), iav[iap - 2], ERR_EXPR);
 
 	/*
 	 * Deal w/ parentheses for grouping.
@@ -452,7 +452,7 @@ e3(void)
 	if (equal(a, "(")) {
 		re = expr();
 		if (!equal(nxtarg(RETERR), ")"))
-			err(FC_ERR, FMT3S, getmyname(), a, ERR_PAREN);
+			sh_err(FC_ERR, FMT3S, getmyname(), a, ERR_PAREN);
 		return re;
 	}
 
@@ -461,7 +461,7 @@ e3(void)
 	 */
 	if (equal(a, "{")) {
 		if ((cpid = fork()) == -1)
-			err(FC_ERR, FMT2S, getmyname(), ERR_FORK);
+			sh_err(FC_ERR, FMT2S, getmyname(), ERR_FORK);
 		if (cpid == 0)
 			/**** Child! ****/
 			doex(FORKED);
@@ -502,7 +502,7 @@ e3(void)
 	if (equal(a, "-t")) {
 		/* Does the descriptor refer to a terminal device? */
 		if ((b = nxtarg(RETERR)) == NULL || *b == EOS) {
-			err(FC_ERR, FMT3S, getmyname(), a, ERR_DIGIT);
+			sh_err(FC_ERR, FMT3S, getmyname(), a, ERR_DIGIT);
 			/*NOTREACHED*/
 		}
 		if (*b >= '0' && *b <= '9' && *(b + 1) == EOS) {
@@ -510,7 +510,7 @@ e3(void)
 			if (IS_DIGIT(d, *b))
 				return isatty(d) != 0;
 		}
-		err(FC_ERR, FMT3S, getmyname(), b, ERR_BADDIGIT);
+		sh_err(FC_ERR, FMT3S, getmyname(), b, ERR_BADDIGIT);
 	}
 
 	/* This is the same as "$1" != "", for example, in the shell... */
@@ -525,11 +525,13 @@ e3(void)
 	 * binary comparisons
 	 */
 	if ((b = nxtarg(RETERR)) == NULL)
-		err(FC_ERR, FMT3S, getmyname(), a, ERR_OPERATOR);
-	if (equal(b,  "="))
-		return  equal(a, nxtarg(!RETERR));
+		sh_err(FC_ERR, FMT3S, getmyname(), a, ERR_OPERATOR);
 	if (equal(b, "!="))
 		return !equal(a, nxtarg(!RETERR));
+	if (equal(b, "=="))
+		return  equal(a, nxtarg(!RETERR));
+	if (equal(b,  "="))
+		return  equal(a, nxtarg(!RETERR));
 	if (equal(b, "<"))
 		return strcmp(a, nxtarg(!RETERR)) < 0;
 	if (equal(b, ">"))
@@ -543,7 +545,7 @@ e3(void)
 	if (equal(b, "-eq") || equal(b, "-ne") || equal(b, "-gt") ||
 	    equal(b, "-ge") || equal(b, "-lt") || equal(b, "-le")) {
 		if ((c = nxtarg(RETERR)) == NULL)
-			err(FC_ERR, FMT3S, getmyname(), b, ERR_INTEGER);
+			sh_err(FC_ERR, FMT3S, getmyname(), b, ERR_INTEGER);
 		if (strtoint(a, &ai) && strtoint(c, &ci)) {
 			if (equal(b, "-eq"))
 				return ai == ci;
@@ -558,9 +560,9 @@ e3(void)
 			if (equal(b, "-le"))
 				return ai <= ci;
 		} else
-			err(FC_ERR, NULL);
+			sh_err(FC_ERR, NULL);
 	}
-	err(FC_ERR, FMT3S, getmyname(), b, ERR_OPUNKNOWN);
+	sh_err(FC_ERR, FMT3S, getmyname(), b, ERR_OPUNKNOWN);
 	/*NOTREACHED*/
 	return false;
 }
@@ -572,7 +574,7 @@ doex(bool forked)
 	char **xap, **xav;
 
 	if (iap < 2 || iap > iac)	/* should never (but can) be true */
-		err(FC_ERR, FMT2S, getmyname(), ERR_AVIINVAL);
+		sh_err(FC_ERR, FMT2S, getmyname(), ERR_AVIINVAL);
 
 	xav = xap = &iav[iap];
 	while (*xap != NULL) {
@@ -581,14 +583,14 @@ doex(bool forked)
 		xap++;
 	}
 	if (forked && xap - xav > 0 && !equal(*xap, "}"))
-		err(FC_ERR, FMT3S, getmyname(), iav[iap - 1], ERR_BRACE);
+		sh_err(FC_ERR, FMT3S, getmyname(), iav[iap - 1], ERR_BRACE);
 	*xap = NULL;
 	if (xav[0] == NULL) {
 		if (forked)
-			err(FC_ERR, FMT3S, getmyname(), iav[iap - 1], ERR_COMMAND);
+			sh_err(FC_ERR, FMT3S, getmyname(), iav[iap - 1], ERR_COMMAND);
 		else
 			/* Currently unreachable; do not remove. */
-			err(FC_ERR, FMT2S, getmyname(), ERR_COMMAND);
+			sh_err(FC_ERR, FMT2S, getmyname(), ERR_COMMAND);
 	}
 
 	/* Invoke the ":" or "exit" special command. */
@@ -608,7 +610,7 @@ doex(bool forked)
 		return;
 	}
 
-	(void)err_pexec(xav[0], xav);
+	(void)pexec_err(xav[0], xav);
 }
 
 /*
@@ -702,14 +704,14 @@ nxtarg(bool reterr)
 	char *nap;
 
 	if (iap < 1 || iap > iac)	/* should never (but can) be true */
-		err(FC_ERR, FMT2S, getmyname(), ERR_AVIINVAL);
+		sh_err(FC_ERR, FMT2S, getmyname(), ERR_AVIINVAL);
 
 	if (iap == iac) {
 		if (reterr) {
 			iap++;
 			return NULL;
 		}
-		err(FC_ERR, FMT3S, getmyname(), iav[iap - 1], ERR_ARGUMENT);
+		sh_err(FC_ERR, FMT3S, getmyname(), iav[iap - 1], ERR_ARGUMENT);
 	}
 	nap = iav[iap];
 	iap++;
